==> pegtl-2.7.1-2-any.pkg.tar.xz: usr/include/tao/pegtl/internal/one.hpp <==
// Copyright (c) 2014-2018 Dr. Colin Hirsch and Daniel Frey
// Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/

#ifndef TAO_PEGTL_INTERNAL_ONE_HPP
#define TAO_PEGTL_INTERNAL_ONE_HPP

#include <algorithm>
#include <utility>

#include "../config.hpp"

#include "bump_help.hpp"
#include "result_on_found.hpp"
#include "skip_control.hpp"

#include "../analysis/generic.hpp"

namespace tao
{
   namespace TAO_PEGTL_NAMESPACE
   {
      namespace internal
      {
         template< typename Char >
         bool contains( const Char c, const std::initializer_list< Char >& l ) noexcept
         {
            return std::find( l.begin(), l.end(), c ) != l.end();
         }

         template< result_on_found R, typename Peek, typename Peek::data_t... Cs >
         struct one
         {
            using analyze_t = analysis::generic< analysis::rule_type::ANY >;

            template< typename Input >
            static bool match( Input& in ) noexcept( noexcept( in.empty() ) )
            {
               if( !in.empty() ) {
                  if( const auto t = Peek::peek( in ) ) {
                     if( contains( t.data, { Cs... } ) == bool( R ) ) {
                        bump_help< R, Input, typename Peek::data_t, Cs... >( in, t.size );
                        return true;
                     }
                  }
               }
               return false;
            }
         };

         template< result_on_found R, typename Peek, typename Peek::data_t C >
         struct one< R, Peek, C >
         {
            using analyze_t = analysis::generic< analysis::rule_type::ANY >;

            template< typename Input >
            static bool match( Input& in ) noexcept( noexcept( in.empty() ) )
            {
               if( !in.empty() ) {
                  if( const auto t = Peek::peek( in ) ) {
                     if( ( t.data == C ) == bool( R ) ) {
                        bump_help< R, Input, typename Peek::data_t, C >( in, t.size );
                        return true;
                     }
                  }
               }
               return false;
            }
         };

         template< result_on_found R, typename Peek, typename Peek::data_t... Cs >
         struct skip_control< one< R, Peek, Cs... > > : std::true_type
         {
         };

      }  // namespace internal

   }  // namespace TAO_PEGTL_NAMESPACE

}  // namespace tao

#endif

==> pegtl-2.8.1-1-any.pkg.tar.xz: usr/include/tao/pegtl/internal/one.hpp <==
// Copyright (c) 2014-2019 Dr. Colin Hirsch and Daniel Frey
// Please see LICENSE for license or visit https://github.com/taocpp/PEGTL/

#ifndef TAO_PEGTL_INTERNAL_ONE_HPP
#define TAO_PEGTL_INTERNAL_ONE_HPP

#include <algorithm>
#include <utility>

#include "../config.hpp"

#include "bump_help.hpp"
#include "result_on_found.hpp"
#include "skip_control.hpp"

#include "../analysis/generic.hpp"

namespace tao
{
   namespace TAO_PEGTL_NAMESPACE
   {
      namespace internal
      {
         template< typename Char >
         bool contains( const Char c, const std::initializer_list< Char >& l ) noexcept
         {
            return std::find( l.begin(), l.end(), c ) != l.end();
         }

         template< result_on_found R, typename Peek, typename Peek::data_t... Cs >
         struct one
         {
            using analyze_t = analysis::generic< analysis::rule_type::any >;

            template< typename Input >
            static bool match( Input& in ) noexcept( noexcept( in.size( Peek::max_input_size ) ) )
            {
               const std::size_t s = in.size( Peek::max_input_size );
               if( s >= Peek::min_input_size ) {
                  if( const auto t = Peek::peek( in, s ) ) {
                     if( contains( t.data, { Cs... } ) == bool( R ) ) {
                        bump_help< R, Input, typename Peek::data_t, Cs... >( in, t.size );
                        return true;
                     }
                  }
               }
               return false;
            }
         };

         template< result_on_found R, typename Peek, typename Peek::data_t C >
         struct one< R, Peek, C >
         {
            using analyze_t = analysis::generic< analysis::rule_type::any >;

            template< typename Input >
            static bool match( Input& in ) noexcept( noexcept( in.size( Peek::max_input_size ) ) )
            {
               const std::size_t s = in.size( Peek::max_input_size );
               if( s >= Peek::min_input_size ) {
                  if( const auto t = Peek::peek( in, s ) ) {
                     if( ( t.data == C ) == bool( R ) ) {
                        bump_help< R, Input, typename Peek::data_t, C >( in, t.size );
                        return true;
                     }
                  }
               }
               return false;
            }
         };

         template< result_on_found R, typename Peek, typename Peek::data_t... Cs >
         struct skip_control< one< R, Peek, Cs... > > : std::true_type
         {
         };

      }  // namespace internal

   }  // namespace TAO_PEGTL_NAMESPACE

}  // namespace tao

#endif
